@@ -1,7 +1,7 @@
 /*
  * Copyright 2005 Jeff Francis <jeff@gritch.org>
  *
- * This file is Copyright 2005 by the GPSD project
+ * This file is Copyright by the GPSD project
  * SPDX-License-Identifier: BSD-2-clause
  */
 
@@ -128,6 +128,7 @@ static bool rtk_flag = false;
 #define GPS_ERROR       -2      // low-level failure in GPS read
 #define GPS_TIMEOUT     -3      // low-level failure in GPS waiting
 #define CGPS_ERROR      -4      // low-level curses failure
+#define CGPS_SIZE       -5      // terminal too small
 
 /* range test an int,
  * Return: chars + NUL
@@ -204,13 +205,14 @@ static char *ecef_to_str(double pos, double vel)
                            vel * altfactor, altunits);
         }
     } else {
+        // u-blox F9  HPG is 0.1 mm.  So 14.4f
         if (0 == isfinite(vel)) {
             // have position, no velocity
-            (void)snprintf(buf, sizeof(buf), "% 14.3f %2.2s   n/a       ",
+            (void)snprintf(buf, sizeof(buf), "% 14.4f %2.2s   n/a       ",
                            pos * altfactor, altunits);
         } else {
             // have position, have velocity
-            (void)snprintf(buf, sizeof(buf), "% 14.3f %2.2s % 8.3f %2.2s/s",
+            (void)snprintf(buf, sizeof(buf), "% 14.4f %2.2s % 8.3f %2.2s/s",
                            pos * altfactor, altunits,
                            vel * altfactor, altunits);
         }
@@ -247,6 +249,7 @@ static void die(int sig, const char *msg)
 
     switch (sig) {
     case CGPS_QUIT:
+        exit(EXIT_SUCCESS);
         break;
     case GPS_GONE:
         (void)fprintf(stderr, "cgps: GPS hung up.\n");
@@ -260,13 +263,16 @@ static void die(int sig, const char *msg)
     case CGPS_ERROR:
         (void)fprintf(stderr, "cgps: internal error\n");
         break;
+    case CGPS_SIZE:
+        exit(2);
+        break;
     default:
         (void)fprintf(stderr, "cgps: caught signal %d\n", sig);
         break;
     }
 
     // Bye!
-    exit(EXIT_SUCCESS);
+    exit(EXIT_FAILURE);
 }
 
 
@@ -363,7 +369,8 @@ static void windowsetup(void)
 
         if ((IMU_WIDTH - 2) > COLS) {
             // allow 78, cutting of the two rightmost columns is acceptable
-            die(0, "Your terminal not wide enough.  80 columns required.");
+            die(CGPS_SIZE,
+                "Your terminal not wide enough.  80 columns required.");
         }
 
         if (MIN_COMPASS_DATAWIN_YSIZE == ysize) {
@@ -373,63 +380,72 @@ static void windowsetup(void)
             raw_flag = true;
             window_ysize = MIN_COMPASS_DATAWIN_YSIZE;
         } else {
-            die(0, "Your terminal does not have enough rows run cgps.");
+            die(CGPS_SIZE, "Your terminal does not have enough rows run cgps.");
         }
 
         datawin = newwin(window_ysize, IMU_WIDTH, 0, 0);
 
         // do not block waiting for user input
         if (OK != nodelay(datawin, true)) {
-            die(0, "Fail creating datawin window.");
+            die(CGPS_ERROR, "Fail creating datawin window.");
         }
 
         if (NULL != messages) {
-            (void)delwin(messages);
+            if (OK != delwin(messages)) {
+                die(CGPS_ERROR, "Fail delwin(messages)");
+            }
             messages = NULL;
         }
         if (raw_flag) {
             messages = newwin(0, 0, window_ysize, 0);
+            /* FIXME?  how to check messages?
+             * "man newwin" says ERR == messages, but ERR is int, and
+             * messages is pointer. */
 
             if (OK != scrollok(messages, true) ||
                 OK != wsetscrreg(messages, 0, ysize - (window_ysize))) {
-                die(0, "Fail creating message window.");
+                die(CGPS_ERROR, "Fail creating message window.");
             }
         }
 
         // Do the initial IMU field label setup.
-        (void)mvwaddstr(datawin, row++, DATAWIN_DESC_OFFSET, "msg:");
-        (void)mvwaddstr(datawin, row++, DATAWIN_DESC_OFFSET, "Time:");
-        (void)mvwaddstr(datawin, row++, DATAWIN_DESC_OFFSET, "timeTag:");
-        (void)mvwaddstr(datawin, row, DATAWIN_DESC_OFFSET, "Accel X:");
-        (void)mvwaddstr(datawin, row++, IMU_WIDTH - 8, "m/s^2");
-        (void)mvwaddstr(datawin, row, DATAWIN_DESC_OFFSET, "Accel Y:");
-        (void)mvwaddstr(datawin, row++, IMU_WIDTH - 8, "m/s^2");
-        (void)mvwaddstr(datawin, row, DATAWIN_DESC_OFFSET, "Accel Z:");
-        (void)mvwaddstr(datawin, row++, IMU_WIDTH - 8, "m/s^2");
-        (void)mvwaddstr(datawin, row, DATAWIN_DESC_OFFSET, "Gyro T:");
-        (void)mvwaddstr(datawin, row++, IMU_WIDTH - 8, "deg C");
-        (void)mvwaddstr(datawin, row, DATAWIN_DESC_OFFSET, "Gyro X:");
-        (void)mvwaddstr(datawin, row++, IMU_WIDTH - 8, "deg/s^2");
-        (void)mvwaddstr(datawin, row, DATAWIN_DESC_OFFSET, "Gyro Y:");
-        (void)mvwaddstr(datawin, row++, IMU_WIDTH - 8, "deg/s^2");
-        (void)mvwaddstr(datawin, row, DATAWIN_DESC_OFFSET, "Gyro Z:");
-        (void)mvwaddstr(datawin, row++, IMU_WIDTH - 8, "deg/s^2");
-        (void)mvwaddstr(datawin, row++, DATAWIN_DESC_OFFSET, "Mag X:");
-        (void)mvwaddstr(datawin, row++, DATAWIN_DESC_OFFSET, "Mag Y:");
-        (void)mvwaddstr(datawin, row++, DATAWIN_DESC_OFFSET, "Mag Z:");
-        (void)mvwaddstr(datawin, row, DATAWIN_DESC_OFFSET, "True Heading:");
-        (void)mvwaddstr(datawin, row++, IMU_WIDTH - 8, "deg");
-        (void)mvwaddstr(datawin, row, DATAWIN_DESC_OFFSET, "Yaw:");
-        (void)mvwaddstr(datawin, row++, IMU_WIDTH - 8, "deg");
-        (void)mvwaddstr(datawin, row, DATAWIN_DESC_OFFSET, "Pitch:");
-        (void)mvwaddstr(datawin, row++, IMU_WIDTH - 8, "deg");
-        (void)mvwaddstr(datawin, row, DATAWIN_DESC_OFFSET, "Roll:");
-        (void)mvwaddstr(datawin, row++, IMU_WIDTH - 8, "deg");
-        (void)wborder(datawin, 0, 0, 0, 0, 0, 0, 0, 0);
+        if (OK != mvwaddstr(datawin, row++, DATAWIN_DESC_OFFSET, "msg:") ||
+            OK != mvwaddstr(datawin, row++, DATAWIN_DESC_OFFSET, "Time:") ||
+            OK != mvwaddstr(datawin, row++, DATAWIN_DESC_OFFSET, "timeTag:") ||
+            OK != mvwaddstr(datawin, row, DATAWIN_DESC_OFFSET, "Accel X:") ||
+            OK != mvwaddstr(datawin, row++, IMU_WIDTH - 8, "m/s^2") ||
+            OK != mvwaddstr(datawin, row, DATAWIN_DESC_OFFSET, "Accel Y:") ||
+            OK != mvwaddstr(datawin, row++, IMU_WIDTH - 8, "m/s^2") ||
+            OK != mvwaddstr(datawin, row, DATAWIN_DESC_OFFSET, "Accel Z:") ||
+            OK != mvwaddstr(datawin, row++, IMU_WIDTH - 8, "m/s^2") ||
+            OK != mvwaddstr(datawin, row, DATAWIN_DESC_OFFSET, "Gyro T:") ||
+            OK != mvwaddstr(datawin, row++, IMU_WIDTH - 8, "deg C") ||
+            OK != mvwaddstr(datawin, row, DATAWIN_DESC_OFFSET, "Gyro X:") ||
+            OK != mvwaddstr(datawin, row++, IMU_WIDTH - 8, "deg/s^2") ||
+            OK != mvwaddstr(datawin, row, DATAWIN_DESC_OFFSET, "Gyro Y:") ||
+            OK != mvwaddstr(datawin, row++, IMU_WIDTH - 8, "deg/s^2") ||
+            OK != mvwaddstr(datawin, row, DATAWIN_DESC_OFFSET, "Gyro Z:") ||
+            OK != mvwaddstr(datawin, row++, IMU_WIDTH - 8, "deg/s^2") ||
+            OK != mvwaddstr(datawin, row++, DATAWIN_DESC_OFFSET, "Mag X:") ||
+            OK != mvwaddstr(datawin, row++, DATAWIN_DESC_OFFSET, "Mag Y:") ||
+            OK != mvwaddstr(datawin, row++, DATAWIN_DESC_OFFSET, "Mag Z:") ||
+            OK != mvwaddstr(datawin, row, DATAWIN_DESC_OFFSET, "True Heading:") ||
+            OK != mvwaddstr(datawin, row++, IMU_WIDTH - 8, "deg") ||
+            OK != mvwaddstr(datawin, row, DATAWIN_DESC_OFFSET, "Yaw:") ||
+            OK != mvwaddstr(datawin, row++, IMU_WIDTH - 8, "deg") ||
+            OK != mvwaddstr(datawin, row, DATAWIN_DESC_OFFSET, "Pitch:") ||
+            OK != mvwaddstr(datawin, row++, IMU_WIDTH - 8, "deg") ||
+            OK != mvwaddstr(datawin, row, DATAWIN_DESC_OFFSET, "Roll:") ||
+            OK != mvwaddstr(datawin, row++, IMU_WIDTH - 8, "deg") ||
+            OK != wborder(datawin, 0, 0, 0, 0, 0, 0, 0, 0)) {
+            die(CGPS_ERROR, "Fail mvaddstr(datawin,,,) window.");
+        }
         // done with IMU setup
 
         // make it so
-        (void)refresh();
+        if (OK != refresh()) {
+            die(CGPS_ERROR, "Fail refresh() window.");
+        }
         return;
     } // else
 
@@ -438,7 +454,8 @@ static void windowsetup(void)
         int row = 1;
 
         if (RTK_WIDTH > COLS) {
-            die(0, "Your terminal not wide enough.  78 columns required.");
+            die(CGPS_SIZE,
+                "Your terminal not wide enough.  78 columns required.");
         }
 
         if (MIN_COMPASS_DATAWIN_YSIZE == ysize) {
@@ -448,7 +465,7 @@ static void windowsetup(void)
             raw_flag = true;
             window_ysize = MIN_COMPASS_DATAWIN_YSIZE;
         } else {
-            die(0, "Your terminal does not have enough rows run cgps.");
+            die(CGPS_SIZE, "Your terminal does not have enough rows run cgps.");
         }
 
         datawin = newwin(window_ysize, RTK_WIDTH, 0, 0);
@@ -503,7 +520,7 @@ static void windowsetup(void)
     }
     if ((DATAWIN_WIDTH + SATELLITES_WIDTH - 2) > COLS) {
         // allow 78, cutting of the two rightmost columns is acceptable
-        die(0, "Your terminal not wide enough.  80 columns required.");
+        die(CGPS_SIZE, "Your terminal not wide enough.  80 columns required.");
     }
 
     // We're a GPS, set up accordingly.
@@ -550,7 +567,7 @@ static void windowsetup(void)
         show_ecefs = false;
         show_more_dops = false;
     } else {
-        die(0, "Your screen is too small to run cgps.");
+        die(CGPS_SIZE, "Your screen is too small to run cgps.");
     }
 
     // compute datawin rows
@@ -894,9 +911,9 @@ static void update_gps_panel(struct gps_data_t *gpsdata, char *message,
                     break;
                 }
                 if (1 < gpsdata->skyview[sat_no].sigid &&
-                    8 > gpsdata->skyview[sat_no].sigid) {
+                    13 > gpsdata->skyview[sat_no].sigid) {
                     // Do not display L1, or missing
-                    // max is 8
+                    // max is 12, July 2025
                     sigid[0] = '0' + gpsdata->skyview[sat_no].sigid;
                     sigid[1] = '\0';
                 }
@@ -955,7 +972,7 @@ static void update_gps_panel(struct gps_data_t *gpsdata, char *message,
             // Too many sats to show them all, tell the user.
             if (ERR == mvwprintw(satellites, display_sats + 2, 1, "%s",
                                  "More...")) {
-                die(0, "failed to print sat win More");
+                die(CGPS_ERROR, "failed to print sat win More");
             }
         }
     }
@@ -1047,7 +1064,7 @@ static void update_gps_panel(struct gps_data_t *gpsdata, char *message,
                 gpsdata->fix.magnetic_track);
         }
         if (0 == isfinite(gpsdata->fix.magnetic_var)) {
-            (void)strlcat(scr, "      ", sizeof(scr));
+            (void)strlcpy(buf2, "n/a", sizeof(buf2));
         } else {
             (void)snprintf(buf2, sizeof(buf2), "%6.1f",
                            gpsdata->fix.magnetic_var);
@@ -1057,7 +1074,7 @@ static void update_gps_panel(struct gps_data_t *gpsdata, char *message,
         (void)strlcpy(buf2, "n/a", sizeof(buf2));
     }
     (void)mvwprintw(datawin, row++, DATAWIN_DESC_OFFSET,
-                    "Track %-14s %6s,%6s    deg", mag_str, buf1, buf2);
+                    "Track %-14.14s %6.6s,%6.6s    deg", mag_str, buf1, buf2);
 
     // Fill in the rate of climb.
     if (0 == isfinite(gpsdata->fix.climb)) {
@@ -1240,7 +1257,7 @@ static void update_gps_panel(struct gps_data_t *gpsdata, char *message,
         !show_ecefs ||
         !show_more_dops) {
         if (ERR == mvwprintw(datawin, display_sats + 2, 2, "%s", "More...")) {
-            die(0, "failed to print datawin More");
+            die(CGPS_ERROR, "failed to print datawin More");
         }
     }
 
@@ -1260,7 +1277,7 @@ static void update_gps_panel(struct gps_data_t *gpsdata, char *message,
                 // Pacify Coverity 498042, an't happen
                 message_len = 0;
             } else if (message_len >= message_max) {
-                // huh?  Ensure NUL termianted
+                // huh?  Ensure NUL terminated
                 message_len = message_max - 1;
             } else if ( '\r' == message[message_len - 1]) {
                 // remove any trailing \r
