@@ -23,12 +23,14 @@
  *
  */
 
-#include "../include/gpsd_config.h"  /* must be before all includes */
+#undef USE_QT       // this progtam does not work with QT. Pacify Codacy
+
+#include "../include/gpsd_config.h"  // must be before all includes
 
 #include <errno.h>
 #include <fcntl.h>
 #ifdef HAVE_GETOPT_LONG
-       #include <getopt.h>   // for getopt_long()
+    #include <getopt.h>   // for getopt_long()
 #endif
 #include <stdbool.h>
 #include <stdio.h>
@@ -39,16 +41,16 @@
 #include <sys/stat.h>
 #include <sys/time.h>
 #include <sys/types.h>
-#include <time.h>               /* for time_t */
+#include <time.h>               // for time_t
 #include <unistd.h>
 
 #ifdef HAVE_SYS_SOCKET_H
-#include <sys/socket.h>
-#endif /* HAVE_SYS_SOCKET_H */
-#include <termios.h>            /* for speed_t, and cfmakeraw() on some OS */
+    #include <sys/socket.h>
+#endif  // HAVE_SYS_SOCKET_H
+#include <termios.h>            // for speed_t, and cfmakeraw() on some OS
 #ifdef HAVE_WINSOCK2_H
-#include <winsock2.h>
-#endif /* HAVE_WINSOCK2_H */
+    #include <winsock2.h>
+#endif  // HAVE_WINSOCK2_H
 
 #include "../include/gpsd.h"            // for os_daemon()
 
@@ -57,44 +59,44 @@
 static struct gps_data_t gpsdata;
 static void spinner(unsigned int, unsigned int);
 
-/* NMEA-0183 standard baud rate */
+// NMEA-0183 standard baud rate
 #define BAUDRATE B4800
 
-/* Serial port variables */
+// Serial port variables
 static struct termios oldtio, newtio;
-static int fd_out = 1;          /* output initially goes to standard output */
+static int fd_out = STDOUT_FILENO;  // output initially goes to standard output
 static char serbuf[255];
 static int debug;
 
-/* open the serial port and set it up */
+// open the serial port and set it up
 static void open_serial(char *device)
 {
     /*
      * Open modem device for reading and writing and not as controlling
      * tty.
      */
-    if ((fd_out = open(device, O_RDWR | O_NOCTTY)) == -1) {
+    if (-1 == (fd_out = open(device, O_RDWR | O_NOCTTY))) {
         (void)fprintf(stderr, "gpspipe: error opening serial port\n");
         exit(EXIT_FAILURE);
     }
 
-    /* Save current serial port settings for later */
-    if (tcgetattr(fd_out, &oldtio) != 0) {
+    // Save current serial port settings for later
+    if (0 != tcgetattr(fd_out, &oldtio)) {
         (void)fprintf(stderr, "gpspipe: error reading serial port settings\n");
         exit(EXIT_FAILURE);
     }
 
-    /* Clear struct for new port settings. */
+    // Clear struct for new port settings.
     memset(&newtio, 0, sizeof(newtio));
 
-    /* make it raw */
+    // make it raw
     (void)cfmakeraw(&newtio);
-    /* set speed */
+    // set speed
     (void)cfsetospeed(&newtio, BAUDRATE);
 
-    /* Clear the modem line and activate the settings for the port. */
+    // Clear the modem line and activate the settings for the port.
     (void)tcflush(fd_out, TCIFLUSH);
-    if (tcsetattr(fd_out, TCSANOW, &newtio) != 0) {
+    if (0 != tcsetattr(fd_out, TCSANOW, &newtio)) {
         (void)fprintf(stderr, "gpspipe: error configuring serial port\n");
         exit(EXIT_FAILURE);
     }
@@ -107,9 +109,10 @@ static void usage(void)
 #ifdef HAVE_GETOPT_LONG
                   "  --count COUNT    Exit after COUNT packets.\n"
                   "  --daemonize      Run as daemon.\n"
+                  "  --debug LVL      Set debug level to LVL.\n"
                   "  --help           Show this help and exit.\n"
                   "  --json           Dump gpsd native JSON data.\n"
-                  "  --nmea           Dump (psuedo) NMEA.\n"
+                  "  --nmea           Dump (pseudo) NMEA.\n"
                   "  --output FILE    Write output to FILE.\n"
                   "  --pps            Include PPS JSON in NMEA or raw mode.\n"
                   "  --profile        Include profiling info in the JSON.\n"
@@ -124,17 +127,19 @@ static void usage(void)
                   "connecting to gpsd.\n"
                   "  --spinner        Print a little spinner.\n"
                   "  --split24        Set the split24 flag.\n"
-                  "  --timefmt        Set the timestamp format "
+                  "  --timefmt FORMAT Set the timestamp format "
                   "(strftime(3)-like; implies '-t').\n"
                   "  --timestamp      Time stamp the data.\n"
-                  "  --usec           Time stamp in usec, implies -t. "
-                  "Use twice for sec.usec\n"
+                  "  --usec           Time stamp in usec, implies '-t'. "
+                  "Use twice for sec.usec.\n"
                   "  --version        Print version and exit.\n"
+                  "  --nobuffer       do not buffer output\n"
                   "  --zulu           Set the timestamp format to iso8601, "
                   "implies '-t'\n"
 #endif
                   "  -2               Set the split24 flag.\n"
                   "  -d               Run as a daemon.\n"
+                  "  -D LVL           Set debug level to LVL.\n"
                   "  -h               Show this help and exit.\n"
                   "  -l               Sleep for ten seconds before "
                   "connecting to gpsd.\n"
@@ -152,14 +157,15 @@ static void usage(void)
                   "  -T FORMAT        Set the timestamp format "
                   "(strftime(3)-like; implies '-t')\n"
                   "  -t               Time stamp the data.\n"
-                  "  -u               Time stamp in usec, implies -t. "
-                  "Use -uu to output sec.usec\n"
+                  "  -u               Time stamp in usec, implies '-t'. "
+                  "Use -uu to output sec.usec.\n"
                   "  -v               Print a little spinner.\n"
                   "  -V               Print version and exit.\n"
                   "  -w               Dump gpsd native JSON data.\n"
-                  "  -x SEC           Exit after SECONDS delay.\n"
+                  "  -x SEC           Exit after SEC seconds delay.\n"
+                  "  -B               do not buffer output\n"
                   "  -Z               Set the timestamp format to iso8601, "
-                  "implies '-t'\n\n"
+                  "implies '-t'.\n\n"
                   "You must specify one, or more, of: "
                   "--json, --nmea, --raw, -r, -R, or -w\n"
                   "You must use -o if you use -d.\n");
@@ -179,7 +185,7 @@ int main(int argc, char **argv)
     bool new_line = true;
     bool raw = false;
     bool watch = false;
-    bool profile = false;
+    bool nobuffer = false;
     int option_u = 0;                   // option to show uSeconds
     long count = -1;
     time_t exit_timer = 0;
@@ -191,18 +197,20 @@ int main(int argc, char **argv)
     struct fixsource_t source;
     char *serialport = NULL;
     char *outfile = NULL;
-    const char *optstring = "2?dD:hln:o:pPrRwSs:tT:uvVx:Z";
+    const char *optstring = "2?BdD:hln:o:pPrRwSs:tT:uvVx:Z";
+    int err;
 #ifdef HAVE_GETOPT_LONG
     int option_index = 0;
     static struct option long_options[] = {
         {"count", required_argument, NULL, 'n'},
         {"daemonize", no_argument, NULL, 'd'},
+        {"debug", required_argument, NULL, 'D'},
         {"help", no_argument, NULL, 'h'},
         {"json", no_argument, NULL, 'w'},
         {"nmea", no_argument, NULL, 'r' },
         {"output", required_argument, NULL, 'o'},
         {"pps", no_argument, NULL, 'P' },
-        {"profile", no_argument, NULL, 'P' },
+        {"profile", no_argument, NULL, 'p' },
         {"scaled", no_argument, NULL, 'S' },
         {"seconds", required_argument, NULL, 'x'},
         {"serial", no_argument, NULL, 'r' },
@@ -215,6 +223,7 @@ int main(int argc, char **argv)
         {"usec", no_argument, NULL, 'u'},
         {"version", no_argument, NULL, 'V' },
         {"zulu", no_argument, NULL, 'Z'},
+        {"nobuffer", no_argument, NULL, 'B'},
         {NULL, 0, NULL, 0},
     };
 #endif
@@ -228,7 +237,7 @@ int main(int argc, char **argv)
         ch = getopt(argc, argv, optstring);
 #endif
 
-        if (ch == -1) {
+        if (-1 == ch) {
             break;
         }
 
@@ -256,7 +265,7 @@ int main(int argc, char **argv)
             flags |= WATCH_PPS;
             break;
         case 'p':
-            profile = true;
+            flags |= WATCH_TIMING;
             break;
         case 'R':
             flags |= WATCH_RAW;
@@ -306,87 +315,101 @@ int main(int argc, char **argv)
             format = zulu_format;
             iso8601 = true;
             break;
+        case 'B':
+            nobuffer = true;
+            break;
         case '?':
         case 'h':
             usage();
-            exit(0);
+            exit(EXIT_SUCCESS);
         default:
             usage();
             exit(EXIT_FAILURE);
         }
     }
 
-    /* Grok the server, port, and device. */
+    // Grok the server, port, and device.
     if (optind < argc) {
         gpsd_source_spec(argv[optind], &source);
-    } else
+    } else {
         gpsd_source_spec(NULL, &source);
+    }
 
-    if (serialport != NULL && !raw) {
+    if (NULL != serialport &&
+        !raw) {
         (void)fprintf(stderr, "gpspipe: use of '-s' requires '-r'.\n");
         exit(EXIT_FAILURE);
     }
 
-    if (outfile == NULL && daemonize) {
+    if (NULL == outfile &&
+        daemonize) {
         (void)fprintf(stderr, "gpspipe: use of '-d' requires '-o'.\n");
         exit(EXIT_FAILURE);
     }
 
-    if (!raw && !watch && !binary) {
+    if (!raw &&
+        !watch &&
+        !binary) {
         (void)fprintf(stderr,
                       "gpspipe: one of '-R', '-r', or '-w' is required.\n");
         exit(EXIT_FAILURE);
     }
 
-    /* Daemonize if the user requested it. */
-    if (daemonize)
-        if (os_daemon(0, 0) != 0)
+    // Daemonize if the user requested it.
+    if (daemonize) {
+        if (0 != os_daemon(0, 0)) {
             (void)fprintf(stderr,
                           "gpspipe: daemonization failed: %s\n",
                           strerror(errno));
+        }
+    }
 
-    /* Sleep for ten seconds if the user requested it. */
-    if (sleepy)
+    // Sleep for ten seconds if the user requested it.
+    if (sleepy) {
         (void)sleep(10);
+    }
 
-    /* Open the output file if the user requested it.  If the user
+    /* Open the output file if the user requested it. If the user
      * requested '-R', we use the 'b' flag in fopen() to "do the right
      * thing" in non-linux/unix OSes. */
-    if (outfile == NULL) {
+    if (NULL == outfile) {
         fp = stdout;
     } else {
-        if (binary)
-            fp = fopen(outfile, "wb");
-        else
-            fp = fopen(outfile, "w");
-
-        if (fp == NULL) {
+        fp = fopen(outfile, binary ? "wb" : "w");
+        if (NULL == fp) {
             (void)fprintf(stderr,
-                          "gpspipe: unable to open output file:  %s\n",
+                          "gpspipe: unable to open output file: %s\n",
                           outfile);
             exit(EXIT_FAILURE);
         }
     }
+    if (nobuffer) {
+        setbuf(fp, NULL);    // do NOT buffer output
+    }
 
-    /* Open the serial port and set it up. */
-    if (serialport)
+
+    // Open the serial port and set it up.
+    if (serialport) {
         open_serial(serialport);
+    }
 
-    if (gps_open(source.server, source.port, &gpsdata) != 0) {
+    err = gps_open(source.server, source.port, &gpsdata);
+    if (0 != err) {
         (void)fprintf(stderr,
-                      "gpspipe: could not connect to gpsd %s:%s, %s(%d)\n",
-                      source.server, source.port, gps_errstr(errno), errno);
+                      "gpspipe: gps_open() failed  %s(%d) errno %s(%d)\n",
+                      gps_errstr(err), err, strerror(errno), errno);
         exit(EXIT_FAILURE);
     }
 
-    if (profile)
-        flags |= WATCH_TIMING;
-    if (source.device != NULL)
+    if (NULL != source.device) {
         flags |= WATCH_DEVICE;
+    }
     (void)gps_stream(&gpsdata, flags, source.device);
 
-    if ((isatty(STDERR_FILENO) == 0) || daemonize)
+    if (0 == (isatty(STDERR_FILENO)) ||
+        daemonize) {
         vflag = 0;
+    }
 
     for (;;) {
         int r = 0;
@@ -397,31 +420,39 @@ int main(int argc, char **argv)
         FD_ZERO(&fds);
         FD_SET(gpsdata.gps_fd, &fds);
         errno = 0;
-        r = pselect(gpsdata.gps_fd+1, &fds, NULL, NULL, &tv, NULL);
-        if (r >= 0 && exit_timer && time(NULL) >= exit_timer)
-                break;
-        if (r == -1 && errno != EINTR) {
+        r = pselect(gpsdata.gps_fd + 1, &fds, NULL, NULL, &tv, NULL);
+        if (0 <= r &&
+            exit_timer &&
+            time(NULL) >= exit_timer) {
+            break;
+        }
+        if (-1 == r &&
+            EINTR != errno) {
             (void)fprintf(stderr, "gpspipe: select error %s(%d)\n",
                           strerror(errno), errno);
             exit(EXIT_FAILURE);
-        } else if (r == 0)
-                continue;
+        } else if (0 == r) {
+            continue;
+        }
 
-        if (vflag)
+        if (vflag) {
             spinner(vflag, l++);
+        }
 
-        /* reading directly from the socket avoids decode overhead */
+        // reading directly from the socket avoids decode overhead
         errno = 0;
         r = (int)recv(gpsdata.gps_fd, buf, sizeof(buf), 0);
-        if (r > 0) {
+        if (0 < r) {
             int i = 0;
             int j = 0;
+
             for (i = 0; i < r; i++) {
                 char c = buf[i];
-                if (j < (int)(sizeof(serbuf) - 1)) {
+                if ((int)(sizeof(serbuf) - 1) > j) {
                     serbuf[j++] = buf[i];
                 }
-                if (new_line && timestamp) {
+                if (new_line &&
+                    timestamp) {
                     char tmstr_u[40];            // time with "usec" resolution
                     struct timespec now;
                     struct tm tmp_now;
@@ -430,12 +461,13 @@ int main(int argc, char **argv)
                     (void)clock_gettime(CLOCK_REALTIME, &now);
                     (void)gmtime_r((time_t *)&(now.tv_sec), &tmp_now);
                     (void)strftime(tmstr, sizeof(tmstr), format, &tmp_now);
-                    new_line = 0;
+                    new_line = false;
 
-                    switch( option_u ) {
+                    switch (option_u) {
                     case 2:
-                        if(iso8601){
-                            written = strlen(tmstr);
+                        if (iso8601) {
+                            // codacy does not like strlen()
+                            written = strnlen(tmstr, sizeof(tmstr));
                             tmstr[written] = 'Z';
                             tmstr[written+1] = '\0';
                         }
@@ -448,32 +480,33 @@ int main(int argc, char **argv)
                         written = snprintf(tmstr_u, sizeof(tmstr_u),
                                            ".%06ld", (long)now.tv_nsec/1000);
 
-                        if((0 < written) && (40 > written) && iso8601){
+                        if ((0 < written) &&
+                            (40 > written) &&
+                            iso8601) {
                             tmstr_u[written-1] = 'Z';
                             tmstr_u[written] = '\0';
                         }
                         break;
                     default:
                         *tmstr_u = '\0';
-                        break;
                     }
 
-                    if (fprintf(fp, "%.24s%s: ", tmstr, tmstr_u) <= 0) {
+                    if (0 >= fprintf(fp, "%.24s%s: ", tmstr, tmstr_u)) {
                         (void)fprintf(stderr,
                                       "gpspipe: write error, %s(%d)\n",
                                       strerror(errno), errno);
                         exit(EXIT_FAILURE);
                     }
                 }
-                if (fputc(c, fp) == EOF) {
+                if (EOF == fputc(c, fp)) {
                     (void)fprintf(stderr, "gpspipe: write error, %s(%d)\n",
                                   strerror(errno), errno);
                     exit(EXIT_FAILURE);
                 }
 
-                if (c == '\n') {
-                    if (serialport != NULL) {
-                        if (write(fd_out, serbuf, (size_t) j) == -1) {
+                if ('\n' == c) {
+                    if (NULL != serialport) {
+                        if (-1 == write(fd_out, serbuf, (size_t) j)) {
                             (void)fprintf(stderr,
                                           "gpspipe: serial port write error,"
                                           " %s(%d)\n",
@@ -484,28 +517,28 @@ int main(int argc, char **argv)
                     }
 
                     new_line = true;
-                    /* flush after every good line */
+                    // flush after every good line
                     if (fflush(fp)) {
                         (void)fprintf(stderr,
                                       "gpspipe: fflush error, %s(%d)\n",
                                       strerror(errno), errno);
                         exit(EXIT_FAILURE);
                     }
-                    if (count > 0) {
-                        if (0 >= --count) {
-                            /* completed count */
-                            exit(EXIT_SUCCESS);
-                        }
+                    if (0 < count &&
+                        0 >= --count) {
+                        // completed count
+                        exit(EXIT_SUCCESS);
                     }
                 }
             }
         } else {
-            if (r == -1) {
-                if (errno == EAGAIN)
+            if (-1 == r) {
+                if (EAGAIN == errno) {
                     continue;
-                else
+                } else {
                     (void)fprintf(stderr, "gpspipe: read error %s(%d)\n",
                               strerror(errno), errno);
+                }
                 exit(EXIT_FAILURE);
             } else {
                 exit(EXIT_SUCCESS);
@@ -514,26 +547,24 @@ int main(int argc, char **argv)
     }
 
 #ifdef __UNUSED__
-    if (serialport != NULL) {
-        /* Restore the old serial port settings. */
+    if (NULL != serialport) {
+        // Restore the old serial port settings.
         if (tcsetattr(fd_out, TCSANOW, &oldtio) != 0) {
             (void)fprintf(stderr,
                           "gpsipe: error restoring serial port settings\n");
             exit(EXIT_FAILURE);
         }
     }
-#endif /* __UNUSED__ */
+#endif  // __UNUSED__
 
     exit(EXIT_SUCCESS);
 }
 
-
 static void spinner(unsigned int v, unsigned int num)
 {
     char *spin = "|/-\\";
 
     (void)fprintf(stderr, "\010%c", spin[(num / (1 << (v - 1))) % 4]);
     (void)fflush(stderr);
-    return;
 }
 // vim: set expandtab shiftwidth=4
