@@ -155,7 +155,7 @@ static void gpsd_vlog(const int errlevel,
             err_str = "RAW";
             level = LOG_DEBUG;
             break;
-    case LOG_RAW1:       // 9, rediculous
+    case LOG_RAW1:       // 9, ridiculous
             err_str = "RAW1";
             level = LOG_DEBUG;
             break;
@@ -357,7 +357,7 @@ void gpsd_init(struct gps_device_t *session, struct gps_context_t *context,
     gpsd_zero_satellites(&session->gpsdata);
 
     // initialize things for the packet parser
-    packet_reset(&session->lexer);
+    lexer_init(&session->lexer, &session->context->errout);
 }
 
 // temporarily release the GPS device
@@ -539,7 +539,7 @@ int parse_uri_dest(char *s, char **host, char **service, char **device)
 
 /* open a device for access to its data *
  * return: the opened file descriptor
- *         PLACEHOLDING_FD (-2) - for /dev/ppsX, ntrip waiting reconenct, etc.
+ *         PLACEHOLDING_FD (-2) - for /dev/ppsX, ntrip waiting reconnect, etc.
  *         UNALLOCATED_FD (-1) - for open failure
  */
 int gpsd_open(struct gps_device_t *session)
@@ -614,7 +614,7 @@ int gpsd_open(struct gps_device_t *session)
                  "CORE: opening UDP feed at %s, port %s.\n", host,
                  port);
         if (0 > (dsock = netlib_connectsock1(AF_UNSPEC, host, port, "udp",
-                                             0, true, NULL, 0))) {
+                                             1, true, NULL, 0))) {
             // cast for 32-bit ints.
             GPSD_LOG(LOG_ERROR, &session->context->errout,
                      "CORE: UDP device open error %s(%ld).\n",
@@ -718,7 +718,7 @@ int gpsd_activate(struct gps_device_t *session, const int mode)
             NULL == session->pps_thread.report_hook) {
             /* it is /dev/ppsX, need to set devicename, etc.
              * check report_hook to ensure not already running
-             * cast fot 32-bit ints */
+             * cast for 32-bit ints */
             GPSD_LOG(LOG_PROG, &session->context->errout,
                      "CORE: to gpsd_clear() fd %ld\n",
                      (long)session->gpsdata.gps_fd);
@@ -871,9 +871,9 @@ static gps_mask_t fill_dop(const struct gpsd_errout_t *errout,
                            const struct gps_data_t * gpsdata,
                            struct dop_t * dop)
 {
-    double prod[4][4] = {0};
-    double inv[4][4] = {0};
-    double satpos[MAXCHANNELS][4] = {0};
+    double prod[4][4] = {{0}};
+    double inv[4][4] = {{0}};
+    double satpos[MAXCHANNELS][4] = {{0}};
     double xdop, ydop, hdop, vdop, pdop, tdop, gdop;
     int i, j, k, n;
 
@@ -923,7 +923,7 @@ static gps_mask_t fill_dop(const struct gpsd_errout_t *errout,
     }
     /* can't use gpsdata->satellites_used as that is a counter for xxGSA,
      * and gets cleared at odd times */
-    GPSD_LOG(LOG_INF, errout, "CORE: Sats used %d visable %d:\n",
+    GPSD_LOG(LOG_INF, errout, "CORE: Sats used %d visible %d:\n",
              n, gpsdata->satellites_visible);
 
     /* If we don't have 4 satellites then we don't have enough
@@ -1604,7 +1604,7 @@ gps_mask_t gpsd_poll(struct gps_device_t *session)
 
             gap = TS_SUB_D(&ts_now, &session->lexer.start_time);
 
-            // used to comare gap > min_cycle, but min_cycle is now
+            // used to compare gap > min_cycle, but min_cycle is now
             // so variable as to be not helpful.  Some GPS models can
             // vary from 20Hz to 1Hz.
             if (gap > quiet_time) {
@@ -1625,7 +1625,8 @@ gps_mask_t gpsd_poll(struct gps_device_t *session)
     }
 
     // can we get a full packet from the device/NTRIP/DGPS/tcp/etc.?
-    if (NULL != session->device_type) {
+    if (NULL != session->device_type &&
+        NULL != session->device_type->get_packet) {
         newlen = session->device_type->get_packet(session);
         // coverity[deref_ptr]
         GPSD_LOG(LOG_RAW, &session->context->errout,
@@ -1741,7 +1742,7 @@ gps_mask_t gpsd_poll(struct gps_device_t *session)
         if (driver_change) {
             const struct gps_type_t **dp;
 
-            for (dp = gpsd_drivers; *dp; dp++)
+            for (dp = gpsd_drivers; *dp; dp++) {
                 if (session->lexer.type == (*dp)->packet_type) {
                     GPSD_LOG(LOG_PROG, &session->context->errout,
                              "CORE: switching to match packet type %d: %s\n",
@@ -1749,6 +1750,12 @@ gps_mask_t gpsd_poll(struct gps_device_t *session)
                     (void)gpsd_switch_driver(session, (*dp)->type_name);
                     break;
                 }
+            }
+            if (NULL == *dp) {
+                GPSD_LOG(LOG_WARN, &session->context->errout,
+                         "CORE: no matching packet type %d\n",
+                         session->lexer.type);
+            }
         }
         session->badcount = 0;
         session->gpsdata.dev.driver_mode =
@@ -2001,7 +2008,7 @@ int gpsd_multipoll(const bool data_ready,
                 GPSD_LOG(LOG_WARN, &device->context->errout,
                          "CORE: connection to ntrip server failed\n");
                 // FIXME: next stat after error should depend on if
-                // initial connect or reconenct...
+                // initial connect or reconnect...
                 device->ntrip.conn_state = NTRIP_CONN_CLOSED;
                 return DEVICE_ERROR;
             }
@@ -2152,7 +2159,7 @@ int gpsd_multipoll(const bool data_ready,
                 GPSD_LOG(LOG_WARN, &device->context->errout,
                          "CORE: 2 connection to ntrip server failed\n");
                 // FIXME: next stat after error should depend on if
-                // initial connect or reconenct...
+                // initial connect or reconnect...
                 device->ntrip.conn_state = NTRIP_CONN_CLOSED;
                 return DEVICE_ERROR;
             }
