@@ -1,7 +1,7 @@
 /* gpsmon.h -- what monitor capabuilities look like
  *
  * By Eric S. Raymond, 2009
- * This file is Copyright 2009 by the GPSD project
+ * This file is Copyright by the GPSD project
  * SPDX-License-Identifier: BSD-2-clause
  */
 
@@ -15,13 +15,13 @@
 #define COMMAND_UNKNOWN         0
 
 struct monitor_object_t {
-    /* a device-specific capability table for the monitor */
-    bool (*initialize)(void);           /* paint legends on windows */
-    void (*update)(void);               /* now paint the data */
-    int (*command)(char[]);             /* interpret device-specific commands */
-    void (*wrap)(void);                 /* deallocate storage */
-    int min_y, min_x;                   /* space required for device info */
-    const struct gps_type_t *driver;    /* device driver table */
+    // a device-specific capability table for the monitor
+    bool (*initialize)(void);           // paint legends on windows
+    void (*update)(void);               // now paint the data
+    int (*command)(char[]);             // interpret device-specific commands
+    void (*wrap)(void);                 // deallocate storage
+    int min_y, min_x;                   // space required for device info
+    const struct gps_type_t *driver;    // device driver table
 };
 
 // Device-specific may need these.
@@ -34,10 +34,10 @@ extern void monitor_complain(const char *fmt, ...);
 
 extern WINDOW *devicewin;
 extern struct gps_device_t      session;
-extern bool serial;     /* True - direct mode, False - daemon mode */
+extern bool serial;     // True - direct mode, False - daemon mode
 void toff_update(WINDOW *, int, int);
 void pps_update(WINDOW *, int, int);
+void pastef(WINDOW *win, int y, int x, int flen, char *fmt, double f);
 
-#endif /* _GPSD_GPSMON_H_ */
-/* gpsmon.h ends here */
+#endif  // _GPSD_GPSMON_H
 // vim: set expandtab shiftwidth=4
