@@ -32,6 +32,17 @@
 #include <QStringList>
 #endif
 
+// decodes for gps_fix_t
+
+// ant_stat
+const struct vlist_t vant_status[] = {
+    {ANT_UNK, "UNK"},     // 0
+    {ANT_OK, "OK"},     // 1
+    {ANT_OPEN, "OPEN"},    // 2
+    {ANT_SHORT, "SHORT"},   // 3
+    {0, NULL},
+};
+
 // gnssId names
 const struct vlist_t vgnssId[] = {
     {0, "GPS"},
@@ -107,6 +118,137 @@ const char *flags2str(unsigned long flags, const struct flist_t *flist,
     return buffer;
 }
 
+/* Translate table from gnmssid/sigid to NMEA sigid, signal name and
+ * RINEX observation code
+ */
+#define SIGID_NUM 16
+struct sig_xlate_t {
+    const char *name;          // plain name
+    const char *obs;           // RINEX observation code
+    uint8_t nmea_sigid;        // NMEA 4.10 signal id.  0 == None
+} const sig_xlate[GNSSID_CNT][SIGID_NUM] = {
+    {   // 0 - GPS
+        {"L1 C/A",   "C1C", 1},
+        {NULL,       NULL},
+        {NULL,       NULL},
+        {"L2 CL",    "C2L", 6},
+        {"L2 CM",    "C2S", 5},
+        {NULL,       NULL},        // 5
+        {"L5 I",     "C5I", 7},
+        {"L5 Q",     "C5Q", 8},
+    },
+    {   // 1- SBAS
+        {"L1C",      "C1C", 1},
+        // {1, "L5I", "C5I"},  // ??
+    },
+    {   // 2 - Galileo
+        {"E1 C",     "C1C", 7},
+        {"E1 B",     "C1B", 7},
+        {NULL,       NULL},
+        {"E5 aI",    "C5I", 1},  // 3
+        {"E5 aQ",    "C5Q", 1},
+        {"E5 bI",    "C7I", 2},
+        {"E5 bQ",    "C7Q", 2},
+        {NULL,       NULL},
+        {"E6 B",     "C6B", 5},   // 8
+        {"E6 C",     "C6C", 5},
+        {"E6 A",     "C6A", 4},
+    },
+    {   // 3 - BeiDou
+        {"B1I D1",   "C2I", 1},
+        {"B1I D2",   "C2I", 1},
+        {"B2I D1",   "C7I", 0xb},
+        {"B2I D2",   "C7I", 0xb},
+        {"B3I D1",   "C6I", 0xb},
+        {"B1 Cp",    "C1P", 3},  // 5
+        {"B1 Cd",    "C1D", 3},
+        {"B2 ap",    "C5P", 5},
+        {"B2 ad",    "C5P", 5},
+        {NULL,       NULL},       // 9
+        {"B3I D2",   "C6I", 0xb},
+    },
+    {   // 4 - IMES
+        {"L5 A",     NULL, 0},
+    },
+    {   // 5 - QZSS
+        {"L1 C/A",   "C1C", 1},
+        {"L1 S",     "C1Z", 4},
+        {NULL,       NULL},
+        {NULL,       NULL},
+        {"L2 CM",    "C2S", 5},
+        {"L2 CL",    "C2L", 6},   // 5
+        {NULL,       NULL},
+        {NULL,       NULL},
+        {"L5 I",     "C5I", 7},
+        {"L5 Q",     "C5Q", 8},
+        {NULL,       NULL},    //  10
+        {NULL,       NULL},
+        {"L1 C/B",   "C1E", 0},
+    },
+    {   // 6 - GLONASS
+        {"L1 OF",    "C1C", 1},
+        {NULL,       NULL},
+        {"L2 OF",    "C2C", 3},
+    },
+    {   // 8 - IRNSS (NavIC)
+        {"L5 A",     "C5A", 1},
+    },
+};
+
+
+/* sigid2str()
+ *
+ * given a gpsd gnssid, and gpsd sigid, return a string for the
+ * sigid.  These are (mostly) UBX compatible.  NOT NMEA compatible.
+ *
+ * See sigid in include/gps.h
+ *
+ * return: static const string
+ */
+const char *sigid2str(unsigned char gnssid, unsigned char sigid)
+{
+    const char *rets = "Unk";
+
+    if (GNSSID_CNT <= gnssid) {
+        rets = "GNSS-Unk";
+    } else if (SIGID_NUM <= sigid) {
+        rets = "SIG-Unk";
+    } else {
+        rets = sig_xlate[gnssid][sigid].name;
+        if (NULL == rets) {
+            rets = "Unk";
+        }
+    }
+
+    return rets;
+}
+
+/* sigid2obs()
+ *
+ * given a gpsd gnssid, and gpsd sigid, return a string for the
+ * RINEX observation code.  These are (mostly) UBX compatible.
+ *  NOT NMEA compatible.
+ *
+ * return: static const string
+ */
+const char *sigid2obs(unsigned char gnssid, unsigned char sigid)
+{
+    const char *rets = "Unk";
+
+    if (GNSSID_CNT <= gnssid) {
+        rets = "GNSS-Unk";
+    } else if (SIGID_NUM <= sigid) {
+        rets = "SIG-Unk";
+    } else {
+        rets = sig_xlate[gnssid][sigid].obs;
+        if (NULL == rets) {
+            rets = "Unk";
+        }
+    }
+
+    return rets;
+}
+
 /* val2str(val, vlist) - given a value, return a matching string.
  *
  * val the value to find in vlist
@@ -170,7 +312,7 @@ double safe_atof(const char *string)
     bool sign = false, expSign = false;
     double fraction, dblExp, *d;
     const char *p;
-    int c;
+    unsigned char c;
     int exp = 0;                // Exponent read from "EX" field.
     int fracExp = 0;            /* Exponent that derives from the fractional
                                  * part.  Under normal circumstatnces, it is
@@ -195,7 +337,7 @@ double safe_atof(const char *string)
     while (isspace((int)*p)) {
         p += 1;
     }
-    if (isdigit((int)*p)) {
+    if (isdigit((unsigned char)*p)) {
         // ignore
     } else if ('-' == *p) {
         sign = true;
@@ -216,7 +358,7 @@ double safe_atof(const char *string)
     decPt = -1;
     for (mantSize = 0; ; mantSize += 1) {
         c = *p;
-        if (!isdigit((int)c)) {
+        if (!isdigit(c)) {
             if ((c != '.') || (decPt >= 0)) {
                 break;
             }
@@ -292,7 +434,7 @@ double safe_atof(const char *string)
             }
             expSign = false;
         }
-        while (isdigit((int) *p)) {
+        while (isdigit((unsigned char) *p)) {
             exp = exp * 10 + (*p - '0');
             if (1024 < exp) {
                 if (true == expSign) {
@@ -394,6 +536,9 @@ void gps_clear_fix(struct gps_fix_t *fixp)
     fixp->ecef.vz = NAN;
     fixp->ecef.pAcc = NAN;
     fixp->ecef.vAcc = NAN;
+    fixp->errEllipseOrient = NAN;
+    fixp->errEllipseMajor = NAN;
+    fixp->errEllipseMinor = NAN;
     fixp->NED.relPosN = NAN;
     fixp->NED.relPosE = NAN;
     fixp->NED.relPosD = NAN;
@@ -588,6 +733,13 @@ void gps_merge_fix(struct gps_fix_t *to,
         to->ecef.vz = from->ecef.vz;
         to->ecef.vAcc = from->ecef.vAcc;
     }
+    if (0 != isfinite(from->errEllipseOrient) &&
+        0 != isfinite(from->errEllipseMajor) &&
+        0 != isfinite(from->errEllipseMinor)) {
+        to->errEllipseOrient = from->errEllipseOrient;
+        to->errEllipseMajor = from->errEllipseMajor;
+        to->errEllipseMinor = from->errEllipseMinor;
+    }
     if (0 != (transfer & NED_SET)) {
         to->NED.relPosN = from->NED.relPosN;
         to->NED.relPosE = from->NED.relPosE;
@@ -619,6 +771,9 @@ void gps_merge_fix(struct gps_fix_t *to,
     if (0 < from->jam) {
         to->jam = from->jam;
     }
+    if (ANT_PWR_UNK != from->ant_power) {
+        to->ant_power = from->ant_power;
+    }
     // navdata stuff.  just wind angle and angle for now
     if (0 != (transfer & NAVDATA_SET)) {
         if (0 != isfinite(from->wanglem)) {
@@ -721,7 +876,12 @@ timespec_t iso8601_to_timespec(const char *isotime)
     if (1 < sl.size()) {
         usec = sl[1].toInt() / pow(10., (double)sl[1].size());
     }
+// toSecsSinceEpoch wasn't introduced until 5.8
+#if QT_VERSION < QT_VERSION_CHECK(5,8,0)
     ret.tv_sec = d.toTime_t();
+#else
+    ret.tv_sec = d.toSecsSinceEpoch();
+#endif
     ret.tv_nsec = usec * 1e9;
 #else  // USE_QT
     double usec = 0;
@@ -965,16 +1125,23 @@ void datum_code_string(int code, char *buffer, size_t len)
 
 /* make up an NMEA 4.0 (extended) PRN based on gnssId:svId,
  * This does NOT match NMEA 4.10 and 4.11 where all PRN are 1-99,
- * except IMEA
+ * except IMES, QZSS, and some SBAS.
+ *
  * Ref Appendix A from u-blox ZED-F9P Interface Description
  * and
  * Section 1.5.3  M10-FW500_InterfaceDescription_UBX-20053845.pdf
  *
- * Return PRN, or zero for error
+ * Using ST Teseo PRN fors for those not defined by UBX.
+ * um3407-teseo-vi-and-teseo-app2nmea-specifications-and-commands-stmicroelectronics.pdf
+ * Section 3.5
+ * But we do not use the per sigId PRNs from ST.
+ *
+ * Return PRN, less than one for error
+ *        -1 for GLONASS svid 255
  */
 short ubx2_to_prn(int gnssId, int svId)
 {
-    short nmea_PRN;
+    short nmea_PRN = 0;
 
     if (1 > svId) {
         // skip 0 svId
@@ -984,24 +1151,17 @@ short ubx2_to_prn(int gnssId, int svId)
     switch (gnssId) {
     case 0:
         // GPS, 1-32 maps to 1-32
-        if (32 < svId) {
-            // skip bad svId
-            return 0;
+        if (32 >= svId) {
+            nmea_PRN = svId;
         }
-        nmea_PRN = svId;
         break;
     case 1:
         // SBAS, 120..151, 152..158 maps to 33..64, 152..158
-        if (120 > svId) {
-            // Huh?
-            return 0;
-        } else if (151 >= svId) {
+        if (120 <= svId &&
+            151 >= svId) {
             nmea_PRN = svId - 87;
         } else if (158 >= svId) {
             nmea_PRN = svId;
-        } else {
-            // Huh?
-            return 0;
         }
         break;
     case 2:
@@ -1014,24 +1174,20 @@ short ubx2_to_prn(int gnssId, int svId)
             return 0;
         } else if (246 >= svId) {
             nmea_PRN = svId + 90;
-        } else {
-            // skip bad svId
-            return 0;
         }
         break;
     case 3:
-        // BeiDou, ubx gnssid:svid 1..37 -> to 401-437
-        // BeiDou, ubx PRN         159..163,33..64 -> to 401-437 ??
-        if (37 >= svId) {
+        /* BeiDou, ubx gnssid:svid    1..37 -> to 401-437
+         * have seen 1-63 on F10 ProtVer 40.0, March 2025
+         *   ubx gnssid:svid    1..63 -> to 401-463
+         * BeiDou, ubx "single svid"  159..163,33..64 -> to 401-437 ?? */
+        if (63 >= svId) {
             nmea_PRN = svId + 400;
         } else if (159 > svId) {
             // skip bad svId
             return 0;
         } else if (163 >= svId) {
             nmea_PRN = svId + 242;
-        } else {
-            // skip bad svId
-            return 0;
         }
         break;
     case 4:
@@ -1044,9 +1200,6 @@ short ubx2_to_prn(int gnssId, int svId)
             return 0;
         } else if (182 >= svId) {
             nmea_PRN = svId;
-        } else {
-            // > 182, skip bad svId
-            return 0;
         }
         break;
     case 5:
@@ -1059,9 +1212,6 @@ short ubx2_to_prn(int gnssId, int svId)
             return 0;
         } else if (202 >= svId) {
             nmea_PRN = svId;
-        } else {
-            // skip bad svId
-            return 0;
         }
         break;
     case 6:
@@ -1073,17 +1223,20 @@ short ubx2_to_prn(int gnssId, int svId)
             return 0;
         } else if (96 >= svId) {
             nmea_PRN = svId;
-        } else {
+        } else if (255 == svId) {
             // skip bad svId, 255 == tracked, but unidentified, skip
-            return 0;
+            nmea_PRN = -1;
         }
         break;
     case 7:
-        // NavIC (IRNSS)
-        FALLTHROUGH
+        // NavIC (IRNSS), 1 - 14 -> 801 - 814
+        if (14 >= svId) {
+            nmea_PRN = svId + 800;;
+        }
+        break;
     default:
         // Huh?
-        return 0;
+        nmea_PRN = 0;
     }
 
     return nmea_PRN;
